@@ -1021,3 +1021,54 @@ def test_trace_context_without_performance(sentry_init):
     assert trace_context["span_id"] == propagation_context.span_id
     assert trace_context["parent_span_id"] == propagation_context.parent_span_id
     assert "dynamic_sampling_context" in trace_context
+
+
+def test_conversation_id_set_get():
+    """Test that set_conversation_id and get_conversation_id work correctly."""
+    scope = Scope()
+    assert scope.get_conversation_id() is None
+
+    scope.set_conversation_id("test-conv-123")
+    assert scope.get_conversation_id() == "test-conv-123"
+
+
+def test_conversation_id_remove():
+    """Test that remove_conversation_id clears the conversation ID."""
+    scope = Scope()
+    scope.set_conversation_id("test-conv-456")
+    assert scope.get_conversation_id() == "test-conv-456"
+
+    scope.remove_conversation_id()
+    assert scope.get_conversation_id() is None
+
+
+def test_conversation_id_overwrite():
+    """Test that set_conversation_id overwrites existing value."""
+    scope = Scope()
+    scope.set_conversation_id("first-conv")
+    scope.set_conversation_id("second-conv")
+    assert scope.get_conversation_id() == "second-conv"
+
+
+def test_conversation_id_copy():
+    """Test that conversation_id is preserved when scope is copied."""
+    scope1 = Scope()
+    scope1.set_conversation_id("copy-test-conv")
+
+    scope2 = copy.copy(scope1)
+    assert scope2.get_conversation_id() == "copy-test-conv"
+
+    # Modifying copy should not affect original
+    scope2.set_conversation_id("modified-conv")
+    assert scope1.get_conversation_id() == "copy-test-conv"
+    assert scope2.get_conversation_id() == "modified-conv"
+
+
+def test_conversation_id_clear():
+    """Test that conversation_id is cleared when scope.clear() is called."""
+    scope = Scope()
+    scope.set_conversation_id("clear-test-conv")
+    assert scope.get_conversation_id() == "clear-test-conv"
+
+    scope.clear()
+    assert scope.get_conversation_id() is None
