@@ -26,15 +26,7 @@ def pytest_generate_tests(metafunc):
 
         metafunc.parametrize(
             "integration_submodule_name",
-            # Temporarily skip some integrations
-            submodule_names
-            - {
-                "clickhouse_driver",
-                "litellm",
-                "pure_eval",
-                "ray",
-                "typer",
-            },
+            submodule_names,
         )
 
 
